@@ -16,7 +16,8 @@ int
 main(int argc, char **argv)
 {
 	struct ncp_conn *conn;
-	__u8 conn_list[256] = {0,};
+	__u8 conn_list[256] =
+	{0,};
 	int no_conn;
 
 	char *message = NULL;
@@ -28,14 +29,12 @@ main(int argc, char **argv)
 		com_err(argv[0], err, "when initializing");
 		exit(1);
 	}
-
 	if (argc != 3)
 	{
 		fprintf(stderr, "usage: %s [options] user message\n", argv[0]);
 		ncp_close(conn);
 		exit(1);
 	}
-
 	user = argv[1];
 	message = argv[2];
 
@@ -46,14 +45,12 @@ main(int argc, char **argv)
 		ncp_close(conn);
 		exit(1);
 	}
-
 	if (no_conn == 0)
 	{
 		fprintf(stderr, "No connection found for %s\n", user);
 		ncp_close(conn);
 		exit(1);
 	}
-
 	if ((err = ncp_send_broadcast(conn, no_conn, conn_list, message)) != 0)
 	{
 		com_err(argv[0], err, "in send_broadcast");
